# review subpackage
__all__ = [
    "replace_rating",
    "shorten_elongation",
    "replace_acronym",
    "remove_acronym",
    "normalize_slangs",
    "expand_contraction",
    "word_normalization"
]